==> wp2-be-metadata-bs-1.0.0-20251229.134916-1-sources.jar: com/finconsgroup/itserr/marketplace/metadata/bs/dto/InputCreateMetadataDto.java <==
package com.finconsgroup.itserr.marketplace.metadata.bs.dto;

import com.finconsgroup.itserr.marketplace.metadata.bs.enums.MetadataCategoryEnum;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.Size;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.Singular;

import java.util.List;

/**
 * Metadata create request DTO.
 */
@Schema(
        name = "MetadataCreateRequest",
        description = "Metadata creation request"
)
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class InputCreateMetadataDto {

    /**
     * Name field length.
     */
    public static final int NAME_LENGTH = 50;

    /**
     * Description field length.
     */
    public static final int DESCRIPTION_LENGTH = 2000;

    @Schema(
            description = "Metadata name",
            example = "Dublin Core (DC)")
    @NotBlank
    @Size(max = NAME_LENGTH)
    private String name;

    @Schema(
            description = "Metadata description",
            example = "Standard metadata for digital resources.")
    @Size(max = DESCRIPTION_LENGTH)
    private String description;

    @Schema(description = "Metadata category")
    private MetadataCategoryEnum category;

    @Schema(description = "Metadata fields")
    @NotEmpty
    @Valid
    @Singular
    private List<InputCreateMetadataFieldDto> fields;

}

==> wp2-be-metadata-bs-1.0.2-20260121.065020-1-sources.jar: com/finconsgroup/itserr/marketplace/metadata/bs/dto/InputCreateMetadataDto.java <==
package com.finconsgroup.itserr.marketplace.metadata.bs.dto;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Size;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.Singular;

import java.util.List;

import static com.finconsgroup.itserr.marketplace.metadata.bs.constants.Constants.METADATA_DESCRIPTION_LENGTH;
import static com.finconsgroup.itserr.marketplace.metadata.bs.constants.Constants.METADATA_NAME_LENGTH;
import static com.finconsgroup.itserr.marketplace.metadata.bs.constants.Constants.VALIDATION_ERROR_REQUIRED_FIELD;

/**
 * Metadata create request DTO.
 */
@Schema(
        name = "MetadataCreateRequest",
        description = "Metadata creation request"
)
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class InputCreateMetadataDto {

    @Schema(
            description = "Metadata name",
            example = "Dublin Core (DC)")
    @NotBlank(message = VALIDATION_ERROR_REQUIRED_FIELD)
    @Size(max = METADATA_NAME_LENGTH)
    private String name;

    @Schema(
            description = "Metadata description",
            example = "Standard metadata for digital resources.")
    @Size(max = METADATA_DESCRIPTION_LENGTH)
    private String description;

    @Schema(description = "Metadata category")
    @NotNull
    private MetadataCategoryEnum category;

    @Schema(description = "Metadata fields")
    @NotEmpty
    @Valid
    @Singular
    private List<InputCreateMetadataFieldDto> fields;

}
